@@ -123,7 +123,7 @@ package Astro::Coord::ECI::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.129_01';
+our $VERSION = '0.130_01';
 our @ISA = qw{Exporter};
 
 use Carp;
@@ -1118,7 +1118,9 @@ Edition, page 116, but his algorithm is for the position angle of the
 first body with respect to the second (i.e. the roles of the two bodies
 are reversed). The order of arguments for this subroutine is consistent
 with The IDL Astronomy User's Library at
-L<https://idlastro.gsfc.nasa.gov/>, function C<posang()>.
+L<https://github.com/wlandsman/IDLAstro>, function C<posang()>. The NASA
+page for this, L<https://asd.gsfc.nasa.gov/archive/idlastro/>, is
+obsolete and no longer updated, but also more descriptive.
 
 This is exposed because in principal you could calculate the position
 angle in any spherical coordinate system, you would just need to get the
@@ -1589,7 +1591,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2023 by Thomas R. Wyant, III
+Copyright (C) 2005-2024 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
